Changelog
=========

1.2.10 (unreleased)
-------------------

- [WEB-3478] slick_slider : Print short date format if show_day_and_month is true.
  [boulch]


1.2.9 (2020-04-28)
------------------

- WEB-3302: Fix bad url in slick css
  [thomlamb]


1.2.8 (2020-04-28)
------------------

- WEB-3302: Implement slick slider
  [mpeeters]

- Remove useless declaration of javascript resources that are not used anyway
  [mpeeters]


1.2.7 (2019-08-05)
------------------

- Fix bug on slider pro.
  [signreaq]


1.2.6 (2019-01-29)
------------------

- Changes value and css for slider vertical.
  [mgennart]

1.2.5 (2019-01-22)
------------------

- Fix click on slider links (restore removed class) : WEB-2898
  [laulaz]


1.2.4 (2019-01-08)
------------------

- Change position to date and category on slider verticals based on collection setting : MWEBOTT-17
  [mgennart]

- Change position to date and category on all sliders based on collection setting : MWEBOTT-17
  [mgennart]

- Add category and dates on all sliders based on collection setting : MWEBOTT-17
  [laulaz]

- Remove unneeded sliders images from html (instead of hiding them)
  [laulaz]

- Remove old archetypes.
  [bsuttor]

- Add a tag to vertical slider.
  [bsuttor]

- Restore vertical slider
  [laulaz]


1.2.3 (2018-05-14)
------------------

- Transform sliders titles into links on index view
  [laulaz]


1.2.2 (2018-04-04)
------------------

- Allow to display / hide titles for sliders
  [laulaz]

- Fix / improve tests & ignores
  [bsuttor]


1.2.1 (2017-07-17)
------------------

- Apply index view filters / values even on sliders : #18026
  [laulaz]

- Remove vertical slider WIP tal code to avoid having to maintain it
  [laulaz]

- Add "Read next" links : #17895
  [laulaz]

- Show publication date in slider-multiple : #17895
  [laulaz]


1.2 (2017-06-15)
----------------

- Add redirection for slider-multiple #17423
  [AuroreMariscal]

- Add video on slide #17396
  [AuroreMariscal]

- Add link for 'see all' on sliders
  [AuroreMariscal]


1.1 (2017-05-08)
----------------

- Add placeholders for slide number / count calculation : #16991
  [laulaz]

- Give id to slider_config to allow multiple sliders on page : #16991
  [laulaz]


1.0.3 (2016-06-27)
------------------

- Use dynamic image scale.
  [bsuttor]

- Use carousel and slider image scale for slider.
  [bsuttor]


1.0.2 (2016-01-21)
------------------

- Add dexterity and plone.app.contenttypes support.
  [bsuttor]


1.0.1 (2015-06-12)
------------------

- Get slider config from cpskin.core to have registry parameters (imio #9515)
  [schminitz]


1.0 (2014-05-06)
----------------

- Initial release
